
import Taro from '@tarojs/taro'
import { View, Button, RadioGroup, Label, Radio, ScrollView } from '@tarojs/components'
import { API_GET_AGENT_BUILDINGS, API_ITEMS_LIST } from '@/constants/api'
import { ROLE_CODE } from '@/constants/user'
import { useSelector } from 'react-redux'
import { fetch } from '@/utils/request'

import { useState, useEffect, useRef } from 'react'
import './style.css'

const wrapAnimate = 'wrap wrapAnimate'
const frameAnimate = 'frame-wrapper'

export default (props) => {
  const { value, onChange, role } = props

  const city = useSelector(state => state.city)

  const [dicts, setDicts] = useState([])
  const [visible, setVisible] = useState(false)
  const [loading, setLoading] = useState(false)
  const [val, setVal] = useState({ buildingName: '意向楼盘' })
  const [buildingTitle, setBuildingTitle] = useState({ buildingName: '意向楼盘' })

  useEffect(() => {
    if (dicts) {
      const building = dicts.filter(x => x.buildingId === value)[0] || { buildingName: '请选择' }
      setVal(building)
    }
  }, [value, dicts])

  useEffect(() => {
    setLoading(true)
    if (role !== ROLE_CODE.CUSTOMER && role !== ROLE_CODE.DRIFT && role !== ROLE_CODE.CONSULTANT) {
      fetch({ url: API_GET_AGENT_BUILDINGS }).then((res) => {
        setDicts(res || [])
        setLoading(false)
      }).catch(() => setLoading(false))
    } else {
      fetch({ url: API_ITEMS_LIST, payload: { pageNumber: 1, pageSize: 1000, cityId: city.curCity.id } }).then((res) => {
        setDicts(res.records)
        setLoading(false)
      }).catch(() => setLoading(false))
    }
  }, [city.curCity.id, role])

  const handleSelect = (e) => {

    const buildingId = e.detail.value
    const building = dicts.filter(x => x.buildingId === buildingId)[0] || { buildingName: '意向楼盘' }

    setBuildingTitle(building)

  }
  const handleSubmit = (e) => {
    e.stopPropagation()
    setVisible(false)
    setVal(buildingTitle)

    onChange(val.buildingId, val)
  }

  return (
    <view>
      {
        visible ? (
          < >
            <view onClick={() => setVisible(false)} className={wrapAnimate}></view>
            <view className={frameAnimate} catchMove>
              <view className='frame'>
                {/* 标题  */}
                <view className='title-wrapper'>
                  <view>{buildingTitle.buildingName}</view>
                </view>
                {/* 内容 */}
                <view style='overflow-x: hidden;'>
                  <View className='page-section'>
                    <View className='radio-list' >
                      <scroll-view
                        scrollY
                        style={{ height: '40vh', overflow: 'hidden' }}
                        catchMove
                      >
                        {loading && '加载中...'}
                        {
                          !loading && (
                            <RadioGroup className='radio-list__RadioGroup' onChange={handleSelect} onClick={e => e.stopPropagation()}>
                              {dicts.map((item, i) => {
                                return (
                                  <Label catchMove className='radio-list__label' for={`rdo-${i}`} key={i}>
                                    <view className='radio-list__text'>{item.buildingName}</view>

                                    <Radio id={`rdo-${i}`} catchMove className='radio-list__radio' value={item.buildingId} checked={item.buildingId === val.buildingId}></Radio>

                                  </Label>
                                )
                              })}
                            </RadioGroup>
                          )
                        }
                      </scroll-view>
                    </View>
                  </View>

                  {/* <view className='bottom-text' onClick={handleTextNext}> */}
                  <view style={{ display: 'flex', margin: '2em auto' }}>
                    <Button className='checkBtn' onClick={() => setVisible(false)}  >取消</Button>
                    <Button className='okBtn' disabled={!buildingTitle.buildingId} onClick={handleSubmit}> 确定</Button>
                  </view>
                  {/* <view className='Btn'>
                    <Button onClick={() => setVisible(false)} >取消</Button>
                    <Button disabled={!val.buildingId} onClick={handleSubmit}>确定</Button>
                  </view> */}
                </view>
              </view>
            </view>
          </>
        ) :
          <View onClick={() => setVisible(true)}>{val.buildingName}</View>
      }
    </view>

  )
}